@@ -32,9 +32,13 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
         super().__init__(*arg, **kwargs)
         self.id = "nuclei"
         self.name = "Nuclei"
-        self.plugin_version = "1.0.0"
+        self.plugin_version = "1.0.1"
         self.version = "2.3.8"
         self.json_keys = {"matched", "templateID", "host"}
+        self._command_regex = re.compile(r'^(sudo nuclei|nuclei|\.\/nuclei|^.*?nuclei)\s+.*?')
+        self.xml_arg_re = re.compile(r"^.*(-o\s*[^\s]+).*$")
+        self._use_temp_file = True
+        self._temp_file_extension = "json"
 
     def parseOutputString(self, output, debug=False):
         for vuln_json in filter(lambda x: x != '', output.split("\n")):
@@ -62,23 +66,29 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
             matched = vuln_dict.get('matched')
             matched_data = urlparse(matched)
             reference = vuln_dict["info"].get('reference', [])
-            if reference:
+            if not reference:
+                reference = []
+            else:
                 if isinstance(reference, str):
                     if re.match('^- ', reference):
-                        reference = list(filter(None, [re.sub('^- ','', elem) for elem in reference.split('\n')]))
+                        reference = list(filter(None, [re.sub('^- ', '', elem) for elem in reference.split('\n')]))
                     else:
                         reference = [reference]
             references = vuln_dict["info"].get('references', [])
             if references:
                 if isinstance(references, str):
                     if re.match('^- ', references):
-                        references = list(filter(None, [re.sub('^- ','', elem) for elem in references.split('\n')]))
+                        references = list(filter(None, [re.sub('^- ', '', elem) for elem in references.split('\n')]))
                     else:
                         references = [references]
+            else:
+                references = []
             cwe = vuln_dict['info'].get('cwe', [])
             capec = vuln_dict['info'].get('capec', [])
-            refs = list(set(reference + references + cwe + capec)).sort()
-            tags = vuln_dict['info'].get('tags', '').split(',')
+            refs = sorted(list(set(reference + references + cwe + capec)))
+            tags = vuln_dict['info'].get('tags', [])
+            if isinstance(tags, str):
+                tags = tags.split(',')
             impact = vuln_dict['info'].get('impact')
             resolution = vuln_dict['info'].get('resolution', '')
             easeofresolution = vuln_dict['info'].get('easeofresolution')
@@ -88,7 +98,7 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
             else:
                 method = ""
             data = [f"Matched: {vuln_dict.get('matched')}",
-                    f"Tags: {vuln_dict['info'].get('tags')}",
+                    f"Tags: {vuln_dict['info'].get('tags', '')}",
                     f"Template ID: {vuln_dict['templateID']}"]
 
             name = vuln_dict["info"].get("name")
@@ -117,8 +127,22 @@ class NucleiPlugin(PluginMultiLineJsonFormat):
                 external_id=f"NUCLEI-{vuln_dict.get('templateID', '')}",
                 run_date=run_date
             )
-
-
+    
+    def processCommandString(self, username, current_path, command_string):
+        """
+        Adds the -oX parameter to get xml output to the command string that the
+        user has set.
+        """
+        super().processCommandString(username, current_path, command_string)
+        arg_match = self.xml_arg_re.match(command_string)
+        if arg_match is None:
+            return re.sub(r"(^.*?nuclei)",
+                          r"\1 --json -irr -o %s" % self._output_file_path,
+                          command_string)
+        else:
+            return re.sub(arg_match.group(1),
+                          r"--json -irr -o %s" % self._output_file_path,
+                          command_string)            
 
 
 def createPlugin(ignore_info=False):
